<xsl:stylesheet	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<!--
 The Apache Software License, Version 1.1

 Copyright (c) 2002 The Apache Software Foundation.  All rights
 reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in
    the documentation and/or other materials provided with the
    distribution.

 3. The end-user documentation included with the redistribution, if
    any, must include the following acknowlegement:
       "This product includes software developed by the
        Apache Software Foundation (http://www.apache.org/)."
    Alternately, this acknowlegement may appear in the software itself,
    if and wherever such third-party acknowlegements normally appear.

 4. The names "The Jakarta Project", "Ant", and "Apache Software
    Foundation" must not be used to endorse or promote products derived
    from this software without prior written permission. For written
    permission, please contact apache@apache.org.

 5. Products derived from this software may not be called "Apache"
    nor may "Apache" appear in their names without prior written
    permission of the Apache Group.

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 ====================================================================

 This software consists of voluntary contributions made by many
 individuals on behalf of the Apache Software Foundation.  For more
 information on the Apache Software Foundation, please see
 <http://www.apache.org/>.
 -->

<xsl:output method="html" indent="yes"/>

<xsl:template match="checkstyle">
	<html>
	<head>
		<title>Checkstyle Analysis</title>
		
	<style type="text/css"><![CDATA[ 
	  body {
		font:normal 68% verdana,arial,helvetica;
		color:#000000;
	  }
	  table tr td, tr th {
		  font-size: 68%;
	  }
	  table.details tr th{
		font-weight: bold;
		text-align:left;
		background:#a6caf0;
	  }
	  table.details tr td{
		background:#eeeee0;
	  }
	  
	  p {
		line-height:1.5em;
		margin-top:0.5em; margin-bottom:1.0em;
		margin-left:2em;
		margin-right:2em;
	  }
	  h1 {
		margin: 0px 0px 5px; font: 165% verdana,arial,helvetica
	  }
	  h2 {
		margin-top: 1em; margin-bottom: 0.5em; font: bold 125% verdana,arial,helvetica
	  }
	  h3 {
		margin-bottom: 0.5em; font: bold 115% verdana,arial,helvetica
	  }
	  h4 {
		margin-bottom: 0.5em; font: bold 100% verdana,arial,helvetica
	  }
	  h5 {
		margin-bottom: 0.5em; font: bold 100% verdana,arial,helvetica
	  }
	  h6 {
		margin-bottom: 0.5em; font: bold 100% verdana,arial,helvetica
	  }
	  .Error {
		font-weight:bold; color:red;
	  }
	  .Failure {
		font-weight:bold; color:purple;
	  }
	  .Properties {
		text-align:right;
	  }]]>
	  </style>
		
		
	</head>
	<body>
	
	<h1><a name="top">Checkstyle Analysis</a></h1>
	<p align="right">Designed for use with <a href="http://checkstyle.sourceforge.net/">Checkstyle</a> and <a href="http://jakarta.apache.org">Ant</a>.</p>
	<hr size="2" />


    <xsl:variable name = "total-errors" select = "count(file/error)" />
    	
    <h2>Summary of <xsl:value-of select="$total-errors"/> errors</h2>	
      <table width="100%" class="details">
	    <tr>
		  <th>Errors</th>
		  <th>File</th>
	     </tr>	 
	<xsl:for-each select = "file">
      <xsl:sort select="count(error)" 
                order="descending"
                data-type="number"/>

	<xsl:if test = "contains(@name,'.java')">
	
    <xsl:variable name = "current-errors" select = "count(error)" />	
	
     <tr>
      <xsl:choose>
		<xsl:when test="$current-errors = 0">
		    	<td>0</td>
		</xsl:when>
	   <xsl:otherwise>
		    	<td bgcolor="red"><xsl:value-of select="$current-errors" /></td>
		</xsl:otherwise>
      </xsl:choose>		   
      	<td><a><xsl:attribute name="href">#<xsl:value-of select="@name" /></xsl:attribute>
      	    <xsl:value-of select="@name" /></a>
      	 </td>   
	  </tr>		
	  
	</xsl:if>	  
	  
	</xsl:for-each>
    </table>

    <h2>Details</h2>
    <xsl:apply-templates select = "file" />	
	
	</body>
	</html>
</xsl:template>


<xsl:template match="file">	
  <xsl:if test = "contains(@name,'.java')">

    <xsl:variable name = "file-errors" select = "count(error)" />

    <xsl:choose>
		<xsl:when test="$file-errors = 0">
		  <table width="100%" class="details">
		    <tr>
		    	<th>
		    	  <xsl:attribute name="name"><xsl:value-of select="@name"/></xsl:attribute>
		    	  <xsl:value-of select="@name"/>
		    	</th>
	     	</tr>				  
		    <tr>
		    	<td>No errors :-)</td>
	     	</tr>		
		   </table> 
		</xsl:when>
	  
		<xsl:otherwise>
		  <table width="100%" class="details">
		    	<th colspan="2">
		    	  <xsl:attribute name="id"><xsl:value-of select="@name"/></xsl:attribute>
		    	  <xsl:value-of select="@name"/>
		    	</th>		  
		    <tr>
		    	<th>Line</th>
		 	    <th>Error</th>
	     	</tr>		
		    <xsl:apply-templates select = "error" />	
		   </table> 
		</xsl:otherwise>
	</xsl:choose>
	
   <hr/>
 </xsl:if>
</xsl:template>


<xsl:template match="error">
			<tr>
				<td align="left"><xsl:value-of select="@line"/></td>
				<td align="left"><xsl:value-of select="@message"/></td>
			</tr>	     	
</xsl:template>

</xsl:stylesheet>
